@@ -1,9 +1,14 @@
 import datetime
-from nonebot.plugin import on_command
+
+from nonebot import get_bot, get_driver, require
+from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, Message, NetworkError
+from nonebot.matcher import Matcher
+from nonebot.params import CommandArg
 from nonebot.permission import SUPERUSER
-from nonebot.adapters.cqhttp import GroupMessageEvent, Event, Bot
-from nonebot.typing import Union, T_State
-from nonebot import require, get_bot, get_driver
+from nonebot.plugin import on_command
+from nonebot.typing import Union
+from nonebot.log import logger
+
 from .data_source import LoLMatch
 
 __author__ = "Alex Newton"
@@ -14,36 +19,48 @@ __usage__ = """
         附带命令 订阅 [tournamentID] 订阅相关系列赛 每晚检查当日结果和第二天赛程
         附带命令 赛事 查看所有即将进行或正在进行的赛事
 """
-__version__ = '0.1.0'
+__version__ = '0.1.5'
 __plugin_name__ = "LOL比赛信息插件"
 scheduler = require('nonebot_plugin_apscheduler').scheduler
 
-lol_today = on_command('lol', aliases={'LOL', "Lol"}, priority=5)
+lol_today = on_command('lol', aliases={'LOL'}, priority=5, block=True)
+test = on_command('test', permission=SUPERUSER, block=True)
+
 driver = get_driver()
 driver.on_startup(LoLMatch.creat_table)
 
 
 @lol_today.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
-    msg: str = str(event.get_message()).strip()
-    if '本周' in msg:
+async def _(matcher: Matcher, event: GroupMessageEvent, args: Message = CommandArg()):
+    msg: str = args.extract_plain_text().strip()
+    if "本周" in msg:
         await lol_today.finish(await LoLMatch.show_week_matches())
-    elif '详情' in msg:
-        index_msg = msg.replace('详情', '').strip()
+    elif "查看订阅" in msg:
+        try:
+            await lol_today.finish(await LoLMatch.show_subbed_tournament(event.group_id))
+        except ValueError:
+            await lol_today.finish("检查输入赛事ID应为数字")
+    elif "详情" in msg:
+        index_msg = msg.replace("详情", "").strip()
         try:
             index = int(index_msg)
-            await lol_today.finish(await LoLMatch.show_match_details(bot, event, index))
+            await lol_today.finish(await LoLMatch.show_match_details(matcher, index))
         except ValueError:
-            await lol_today.finish('检查输入matchID应为数字')
-    elif '订阅' in msg:
-        sub_id = msg.replace('订阅', '').strip()
-        await LoLMatch.sub_tournament_group(int(sub_id), event.group_id)
-    elif '赛事' in msg:
+            await lol_today.finish("检查输入比赛ID应为数字")
+    elif "订阅" in msg:
+        sub_id = msg.replace("订阅", '').strip()
+        await lol_today.finish(await LoLMatch.sub_tournament_group(int(sub_id), event.group_id))
+    elif "赛事" in msg:
         await lol_today.finish(await LoLMatch.show_all_tournaments())
     else:
         await lol_today.finish(await LoLMatch.show_today_matches())
 
 
+@test.handle()
+async def _():
+    await match_checker()
+
+
 # 每日23点自动检查比赛
 @scheduler.scheduled_job('cron', hour=23, jitter=30, id='lol_check_match')
 async def match_checker():
@@ -51,9 +68,9 @@ async def match_checker():
         bot: Bot = get_bot()  # 当未连接bot时返回
     except ValueError:
         return
-    subed = await LoLMatch.get_sub_tournament()  # 获得所有订阅的tournament
+    subbed = await LoLMatch.get_sub_tournament()  # 获得所有订阅的tournament
     sub_dict: dict = {}
-    for sub in subed:
+    for sub in subbed:
         sub_dict[sub['tournament']] = sub['group_id']
     match_data = await LoLMatch.get_week_matches()
     sub_tournament = sub_dict.keys()
@@ -68,10 +85,13 @@ async def match_checker():
         for tournamentID, tournament_matches in today_matches.items():
             if int(tournamentID) not in sub_tournament:
                 continue  # 如果比赛不在订阅列表中不做处理
-            match_result = _msg + f"{tournament_matches['tournamentinfo']['short_name']}  ID:{tournamentID}\n" + LoLMatch.match_result_handle(
-                tournament_matches['list'])
+            match_result = _msg + f"{tournament_matches['tournamentinfo']['short_name']}  ID:{tournamentID}\n" + \
+                           LoLMatch.match_result_handle(tournament_matches['list'])
             for group_id in sub_dict[int(tournamentID)]:
-                await bot.send_group_msg(group_id=group_id, message=match_result)
+                try:
+                    await bot.send_group_msg(group_id=group_id, message=match_result)
+                except NetworkError:
+                    logger.warning(f"{__plugin_name__} 向群 {group_id} 发送 {match_result} 失败")
 
     # 处理明日赛程
     tomorrow = datetime.datetime.now() + datetime.timedelta(days=1)
@@ -87,10 +107,14 @@ async def match_checker():
         for tournamentID, tournament_matches in tomorrow_matches.items():
             if int(tournamentID) not in sub_tournament:
                 continue  # 如果比赛不在订阅列表中不做处理
-            match_result = _msg + f"{tournament_matches['tournamentinfo']['short_name']}  ID:{tournamentID}\n" + LoLMatch.match_predict_handle(
-                tournament_matches['list'])
+            match_result = _msg + f"{tournament_matches['tournamentinfo']['short_name']}  ID:{tournamentID}\n" + \
+                           LoLMatch.match_predict_handle(tournament_matches['list'])
             for group_id in sub_dict[int(tournamentID)]:
-                await bot.send_group_msg(group_id=group_id, message=match_result)
+                try:
+                    await bot.send_group_msg(group_id=group_id, message=match_result)
+                except NetworkError:
+                    logger.warning(f"{__plugin_name__} 向群 {group_id} 发送 {match_result} 失败")
+
     available_tour: list = await LoLMatch.get_available_tournament()
     # 检查已结束赛事 脱离数据库
     ava_keys = []
