@@ -5,9 +5,9 @@ from typing import Union, Optional
 import aiohttp
 import ujson as json
 from PIL import Image
-from nonebot import Bot
-from nonebot.adapters.cqhttp import Event, MessageSegment
+from nonebot.adapters.onebot.v11.message import MessageSegment
 from nonebot.log import logger
+from nonebot.matcher import Matcher
 from playwright.async_api import async_playwright
 from sqlalchemy.schema import CreateTable
 from sqlite3 import OperationalError
@@ -17,7 +17,6 @@ api = 'https://www.scoregg.com/services/api_url.php'
 headers = {
     'accept': 'application/json',
     'accept-encoding': 'gzip, deflate',
-    # 'cookie':
 }
 tournament_params = {
     'api_path': '/services/match/web_tournament_group_list.php',
@@ -68,7 +67,6 @@ class LoLMatch:
         初始化数据库
         :return:
         """
-        await init_database()  # 初始化数据库
         statement = CreateTable(sub_tournament)
         try:
             await sqlite_pool.execute(statement)
@@ -80,20 +78,36 @@ class LoLMatch:
 
     @classmethod
     async def tournament_fetch(cls, tournament_id: int):
+        """
+        获得订阅改赛事的群
+        :param tournament_id: 赛事id
+        :return:
+        """
         statement = sub_tournament.select().where(sub_tournament.c.tournament == tournament_id)
         return await sqlite_pool.fetch_one(statement)
 
     @classmethod
     async def del_tournament(cls, tournament_id):
+        """
+        赛事结束，删除该的订阅条目
+        :param tournament_id: 锦标赛id
+        :return:
+        """
         statement = sub_tournament.delete().where(sub_tournament.c.tournament == tournament_id)
         await sqlite_pool.execute(statement)
 
     @classmethod
-    async def tournament_upsert(cls, tournament_id: int, group_id: int):
+    async def tournament_upsert(cls, tournament_id: int, group_id: int) -> bool:
+        """
+        更新订阅的赛事信息
+        :param tournament_id: 锦标赛ID
+        :param group_id: 群号
+        :return: True 为添加成功 False为赛事已存在
+        """
         if (tournament := await cls.tournament_fetch(tournament_id)) is None:
-            print(tournament)
             statement = sub_tournament.insert().values(tournament=tournament_id, group_id=[group_id])
             await sqlite_pool.execute(statement)
+            return True
         else:
             group_list = tournament['group_id']
             if group_list is None:
@@ -103,6 +117,9 @@ class LoLMatch:
                 statement = sub_tournament.update().where(sub_tournament.c.tournament == tournament_id).values(
                     group_id=group_list)
                 await sqlite_pool.execute(statement)
+            else:
+                return False
+            return True
 
     @classmethod
     async def get_sub_tournament(cls, group_id: int = None) -> list:
@@ -122,11 +139,6 @@ class LoLMatch:
                 result.append(tournament)
         return result
 
-    @classmethod
-    async def sub_match_group(cls, group_id: int, matches: Union[int, list]):
-        # TODO
-        statement = sub_match.update().where(sub_match.c.group_id == group_id).values()
-
     @classmethod
     async def get_available_tournament(cls) -> list:
         """
@@ -180,9 +192,12 @@ class LoLMatch:
         :return:
         """
         ava_tour = await cls.get_available_tournament()
-        _msg: str = "系列赛ID  系列赛简写  开始时间\n"
-        for tournament in ava_tour:
-            _msg += f"{tournament['tournamentID']}  {tournament['short_name']}  {tournament['start_date']}\n"
+        if ava_tour:
+            _msg: str = "系列赛ID  锦标赛简写  开始时间\n"
+            for tournament in ava_tour:
+                _msg += f"{tournament['tournamentID']}  {tournament['short_name']}  {tournament['start_date']}\n"
+        else:
+            _msg = "没有正在进行或者即将开始的锦标赛"
         return _msg
 
     @classmethod
@@ -262,6 +277,14 @@ class LoLMatch:
         else:
             return "本周无比赛."
 
+    @classmethod
+    async def show_subbed_tournament(cls, group_id: int) -> str:
+        subbed = await cls.get_sub_tournament(group_id)
+        if subbed:
+            return "已订阅赛事ID: " + " ".join(x['tournament'] for x in subbed)
+        else:
+            return "没有订阅"
+
     @classmethod
     async def get_match_details(cls, match_id: Union[int, str]) -> Optional[dict]:
         """
@@ -282,11 +305,10 @@ class LoLMatch:
         return data_json['data']
 
     @classmethod
-    async def show_match_details(cls, bot: Bot, event: Event, match_id: Union[int, str]) -> Union[str, MessageSegment]:
+    async def show_match_details(cls, matcher: Matcher, match_id: Union[int, str]) -> Union[str, MessageSegment]:
         """
         返回所提供比赛ID的具体信息，包括每小场的截图
-        :param bot:
-        :param event:
+        :param matcher:
         :param match_id: 比赛ID
         :return:
         """
@@ -296,7 +318,7 @@ class LoLMatch:
         match_state: int = int(matches_data['status'])
         _msg = f"ID:{matches_data['matchID']} {state_str[match_state]} {matches_data['tournament_name']}\n"
         if match_state == 2:
-            await bot.send(event, '正在截取结果!')
+            await matcher.send('正在截取结果!')
             _msg += f"----比赛结果----\n{matches_data['team_a_short_name']} {matches_data['team_a_win']} VS {matches_data['team_b_win']} {matches_data['team_b_short_name']}\n"
             result = MessageSegment.text(_msg)
             for pic in await cls.screenshot_for_after_match(matches_data['matchID'], len(matches_data['result_list'])):
@@ -311,9 +333,7 @@ class LoLMatch:
         :param match_round: 比赛打了多少把,必须提供
         :return:
         """
-        async with async_playwright() as p:
-            browser = await p.chromium.launch()
-            page = await browser.new_page()
+        async with get_new_page() as page:
             await page.goto(f"https://www.scoregg.com/match/{match_id}")
             result = []
             for i in range(match_round):
@@ -338,14 +358,22 @@ class LoLMatch:
                     break
                 await page.click(
                     selector=f'#app > div > div.match-main > div.game-link-list > div:nth-child({i + 2})')
-            await browser.close()
         return result
 
     @classmethod
     async def sub_tournament_group(cls, tournament_id: Optional[int], group_id: int):
+        """
+        订阅锦标赛
+        :param tournament_id:
+        :param group_id:
+        :return:
+        """
         if tournament_id is None:
-            all_available = [lambda x: int(i['tournamentID']) for i in await cls.get_available_tournament()]
+            all_available = [int(i['tournamentID']) for i in await cls.get_available_tournament()]
         else:
             all_available = [tournament_id]
         for tournament in all_available:
-            await cls.tournament_upsert(tournament, group_id)
+            if await cls.tournament_upsert(tournament, group_id):
+                return f"赛事ID {tournament_id} 订阅成功"
+            else:
+                return f"赛事ID {tournament_id} 已经订阅"
